@@ -26,7 +26,6 @@
 
 enum {
 	PROP_0,
-	PROP_CURRENT_FOLDER,
 	PROP_FILENAME,
 	PROP_HTML,
 	PROP_HTML_MODE,
@@ -43,6 +42,7 @@ enum {
 	LINK_CLICKED,
 	OBJECT_DELETED,
 	URI_REQUESTED,
+	SPELL_LANGUAGES_CHANGED,
 	LAST_SIGNAL
 };
 
@@ -70,6 +70,8 @@ editor_show_popup_menu (GtkhtmlEditor *editor,
 	html = gtkhtml_editor_get_html (editor);
 	menu = gtkhtml_editor_get_managed_widget (editor, "/context-menu");
 
+	gtk_widget_grab_focus (GTK_WIDGET (html));
+
 	/* Did we right-click in a selection? */
 	in_selection =
 		html_engine_is_selection_active (html->engine) &&
@@ -616,12 +618,6 @@ editor_set_property (GObject *object,
                      GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_CURRENT_FOLDER:
-			gtkhtml_editor_set_current_folder (
-				GTKHTML_EDITOR (object),
-				g_value_get_string (value));
-			return;
-
 		case PROP_FILENAME:
 			gtkhtml_editor_set_filename (
 				GTKHTML_EDITOR (object),
@@ -674,12 +670,6 @@ editor_get_property (GObject *object,
                      GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_CURRENT_FOLDER:
-			g_value_set_string (
-				value, gtkhtml_editor_get_current_folder (
-				GTKHTML_EDITOR (object)));
-			return;
-
 		case PROP_FILENAME:
 			g_value_set_string (
 				value, gtkhtml_editor_get_filename (
@@ -814,17 +804,6 @@ editor_class_init (GtkhtmlEditorClass *class)
 	class->paste_clipboard = editor_paste_clipboard;
 	class->select_all = editor_select_all;
 
-	g_object_class_install_property (
-		object_class,
-		PROP_CURRENT_FOLDER,
-		g_param_spec_string (
-			"current-folder",
-			"Current Folder",
-			"The initial folder for file chooser dialogs",
-			g_get_home_dir (),
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT));
-
 	g_object_class_install_property (
 		object_class,
 		PROP_FILENAME,
@@ -960,6 +939,16 @@ editor_class_init (GtkhtmlEditorClass *class)
 		G_TYPE_NONE, 2,
 		G_TYPE_STRING,
 		G_TYPE_POINTER);
+
+	signals[SPELL_LANGUAGES_CHANGED] = g_signal_new (
+		"spell-languages-changed",
+		G_OBJECT_CLASS_TYPE (class),
+		G_SIGNAL_RUN_LAST,
+		0,
+		NULL, NULL,
+		g_cclosure_marshal_VOID__POINTER,
+		G_TYPE_NONE, 1,
+		G_TYPE_POINTER);
 }
 
 static void
@@ -1167,29 +1156,6 @@ gtkhtml_editor_set_changed (GtkhtmlEditor *editor,
 	g_object_notify (G_OBJECT (editor), "changed");
 }
 
-const gchar *
-gtkhtml_editor_get_current_folder (GtkhtmlEditor *editor)
-{
-	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), NULL);
-
-	return editor->priv->current_folder;
-}
-
-void
-gtkhtml_editor_set_current_folder (GtkhtmlEditor *editor,
-                                   const gchar *current_folder)
-{
-	g_return_if_fail (GTKHTML_IS_EDITOR (editor));
-
-	if (current_folder == NULL)
-		current_folder = g_get_home_dir ();
-
-	g_free (editor->priv->current_folder);
-	editor->priv->current_folder = g_strdup (current_folder);
-
-	g_object_notify (G_OBJECT (editor), "current-folder");
-}
-
 const gchar *
 gtkhtml_editor_get_filename (GtkhtmlEditor *editor)
 {
@@ -1378,40 +1344,6 @@ gtkhtml_editor_set_spell_languages (GtkhtmlEditor *editor,
 	}
 }
 
-gint
-gtkhtml_editor_file_chooser_dialog_run (GtkhtmlEditor *editor,
-                                        GtkWidget *dialog)
-{
-	gint response = GTK_RESPONSE_NONE;
-	gboolean save_folder;
-
-	g_return_val_if_fail (GTKHTML_IS_EDITOR (editor), response);
-	g_return_val_if_fail (GTK_IS_FILE_CHOOSER_DIALOG (dialog), response);
-
-	gtk_file_chooser_set_current_folder_uri (
-		GTK_FILE_CHOOSER (dialog),
-		gtkhtml_editor_get_current_folder (editor));
-
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-
-	save_folder =
-		(response == GTK_RESPONSE_ACCEPT) ||
-		(response == GTK_RESPONSE_OK) ||
-		(response == GTK_RESPONSE_YES) ||
-		(response == GTK_RESPONSE_APPLY);
-
-	if (save_folder) {
-		gchar *folder;
-
-		folder = gtk_file_chooser_get_current_folder_uri (
-			GTK_FILE_CHOOSER (dialog));
-		gtkhtml_editor_set_current_folder (editor, folder);
-		g_free (folder);
-	}
-
-	return response;
-}
-
 /* Helper for gtkhtml_editor_get_text_[html/plain]() */
 static gboolean
 editor_save_receiver (HTMLEngine *engine,
@@ -1809,3 +1741,32 @@ gtkhtml_editor_drop_undo (GtkhtmlEditor *editor)
 
 	gtk_html_drop_undo (html);
 }
+
+void
+gtkthtml_editor_emit_spell_languages_changed (GtkhtmlEditor *editor)
+{
+	GList *languages, *iter;
+
+	g_return_if_fail (editor != NULL);
+
+	languages = NULL;
+	for (iter = editor->priv->active_spell_checkers; iter; iter = g_list_next (iter)) {
+		const GtkhtmlSpellLanguage *language;
+		GtkhtmlSpellChecker *checker = iter->data;
+
+		if (!checker)
+			continue;
+
+		language = gtkhtml_spell_checker_get_language (checker);
+		if (!language)
+			continue;
+
+		languages = g_list_prepend (languages, (gpointer) language);
+	}
+
+	languages = g_list_reverse (languages);
+
+	g_signal_emit (editor, signals[SPELL_LANGUAGES_CHANGED], 0, languages);
+
+	g_list_free (languages);
+}
